@@ -1,11 +1,12 @@
 var indexSectionsWithContent =
 {
-  0: "acgrsv",
-  1: "s",
-  2: "s",
-  3: "acgrs",
-  4: "v",
-  5: "s"
+  0: "abcdefghilmnopqrstvx",
+  1: "afimsx",
+  2: "mqs",
+  3: "abcdefghilmnoprstvx",
+  4: "ehmnvx",
+  5: "x",
+  6: "sx"
 };
 
 var indexSectionNames =
@@ -15,7 +16,8 @@ var indexSectionNames =
   2: "namespaces",
   3: "functions",
   4: "variables",
-  5: "pages"
+  5: "groups",
+  6: "pages"
 };
 
 var indexSectionLabels =
@@ -25,6 +27,7 @@ var indexSectionLabels =
   2: "Namespaces",
   3: "Functions",
   4: "Variables",
-  5: "Pages"
+  5: "Modules",
+  6: "Pages"
 };
 
