@@ -1,11 +1,12 @@
 var indexSectionsWithContent =
 {
-  0: "abcdeghilmnprstvwx",
-  1: "bnwx",
-  2: "w",
-  3: "cdghilmprst",
-  4: "acdehimnrstvwx",
-  5: "w"
+  0: "abcdefghilmnopqrstuvwx",
+  1: "abcfimnopswx",
+  2: "mqw",
+  3: "abcdefghilmnoprstvwx",
+  4: "abcdefhimnoprstuvwx",
+  5: "x",
+  6: "wx"
 };
 
 var indexSectionNames =
@@ -15,7 +16,8 @@ var indexSectionNames =
   2: "namespaces",
   3: "functions",
   4: "variables",
-  5: "pages"
+  5: "groups",
+  6: "pages"
 };
 
 var indexSectionLabels =
@@ -25,6 +27,7 @@ var indexSectionLabels =
   2: "Namespaces",
   3: "Functions",
   4: "Variables",
-  5: "Pages"
+  5: "Modules",
+  6: "Pages"
 };
 
